from setuptools import setup, find_packages

setup(
    name='policy_calculator',
    version='0.1.0',
    packages=find_packages(),
    description='A library for calculating policy prices based on various factors.',
    author='Your Name',
    author_email='your.email@example.com',
    url='https://github.com/yourusername/policy_calculator',
    license='MIT',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
    ],
    python_requires='>=3.6',
)
